// src/logging/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/logging/logger.ts
function createLogger(options = {}) {
  const { level = "info", prefix = "" } = options;
  const logLevels = {
    debug: 0,
    info: 1,
    warn: 2,
    error: 3,
    none: 4
  };
  const currentLevelValue = logLevels[level];
  const formatArgs = (args) => {
    if (args.length === 0) return "";
    return args.map((arg) => {
      if (arg instanceof Error) {
        return `
${arg.stack || arg.message}`;
      }
      if (typeof arg === "object" && arg !== null) {
        return `
${JSON.stringify(arg, null, 2)}`;
      }
      return ` ${String(arg)}`;
    }).join("");
  };
  const shouldLog = (level2) => {
    return logLevels[level2] >= currentLevelValue;
  };
  return {
    debug: (message, ...args) => {
      if (shouldLog("debug")) {
        console.debug(`\x1B[32m${prefix}[DEBUG] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    },
    info: (message, ...args) => {
      if (shouldLog("info")) {
        console.info(`\x1B[34m${prefix}[INFO] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    },
    warn: (message, ...args) => {
      if (shouldLog("warn")) {
        console.warn(`\x1B[33m${prefix}[WARN] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    },
    error: (message, ...args) => {
      if (shouldLog("error")) {
        console.error(`\x1B[31m${prefix}[ERROR] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    }
  };
}
var logger = createLogger();

// src/logging/request-logger.ts
function requestLogger(logger2, name, fn) {
  return async (...args) => {
    const start = Date.now();
    try {
      return await fn(...args);
    } finally {
      const end = Date.now();
      const duration = end - start;
      const body = args[1] ? typeof args[1]?.body === "string" ? args[1]?.body : JSON.stringify(args[1]?.body ?? {}) : "{}";
      const message = `${name} path: ${args[0]}, body: ${body}, took ${formatDuration(duration)}`;
      if (duration > 3e3) {
        logger2.warn(message);
      } else {
        logger2.info(message);
      }
    }
  };
}
function formatDuration(duration) {
  return duration < 1e3 ? `${duration}ms` : `${(duration / 1e3).toFixed(3)}s`;
}
export {
  createLogger,
  maskTokens,
  requestLogger
};
//# sourceMappingURL=logging.mjs.map